==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/webutil/src/com/caucho/xtpdoc/VerboseText.java <==
/*
 * Copyright (c) 1998-2000 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Emil Ong
 */

package com.caucho.xtpdoc;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamWriter;
import java.io.IOException;
import java.io.LineNumberReader;
import java.io.PrintWriter;
import java.io.StringReader;
import java.util.logging.Logger;

public class VerboseText implements ContentItem {
  private Logger log = Logger.getLogger(VerboseText.class.getName());
  private String _text;
  private Document _document;

  public VerboseText(String text, Document document)
  {
    _text = text;
    _document = document;
  }

  public void writeHtml(XMLStreamWriter out)
    throws XMLStreamException
  {
    out.writeCharacters(_text);
  }

  public void writeLaTeX(PrintWriter out)
    throws IOException
  {
    StringReader stringReader = new StringReader(_text);
    LineNumberReader lineReader = new LineNumberReader(stringReader);

    for (String line = lineReader.readLine(); 
         line != null; 
         line = lineReader.readLine()) {
      if (line.length() > 70) {
        log.warning("lines longer than 70 characters will not work in LaTeX");
        log.warning(line);
        log.warning("document: " + _document.getDocumentPath());
      }
    }

    out.print(_text);
  }

  public void writeLaTeXEnclosed(PrintWriter out)
    throws IOException
  {
    writeLaTeX(out);
  }

  public void writeLaTeXTop(PrintWriter out)
    throws IOException
  {
    writeLaTeX(out);
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/webutil/src/com/caucho/xtpdoc/VerboseText.java <==
/*
 * Copyright (c) 1998-2000 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Emil Ong
 */

package com.caucho.xtpdoc;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamWriter;
import java.io.IOException;
import java.io.LineNumberReader;
import java.io.PrintWriter;
import java.io.StringReader;
import java.util.logging.Logger;

public class VerboseText extends AbstractContentItem {
  private Logger log = Logger.getLogger(VerboseText.class.getName());
  private String _text;
  private Document _document;

  public VerboseText(String text, Document document)
  {
    _text = text;
    _document = document;
  }

  public void writeHtml(XMLStreamWriter out)
    throws XMLStreamException
  {
    out.writeCharacters(_text);
  }

  public void writeLaTeX(PrintWriter out)
    throws IOException
  {
    StringReader stringReader = new StringReader(_text);
    LineNumberReader lineReader = new LineNumberReader(stringReader);

    for (String line = lineReader.readLine(); 
         line != null; 
         line = lineReader.readLine()) {
      if (line.length() > 70) {
        log.warning("lines longer than 70 characters will not work in LaTeX");
        log.warning(line);
        log.warning("document: " + _document.getDocumentPath());
      }
    }

    out.print(_text);
  }

  public void writeLaTeXVerbatim(PrintWriter out)
    throws IOException
  {
    writeLaTeX(out);
  }

  public void writeLaTeXEnclosed(PrintWriter out)
    throws IOException
  {
    writeLaTeX(out);
  }

  public void writeLaTeXTop(PrintWriter out)
    throws IOException
  {
    writeLaTeX(out);
  }

  @Override
  public void writeAsciiDoc(PrintWriter out)
    throws IOException
  {
    escapeAsciiDoc(out, _text, true);
  }
}
